#
# spec file for package pngcrush
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pngcrush
Version:        1.8.13
Release:        1.27
Summary:        Optimizer for PNG Files that can also insert or delete specified Chunks
License:        Zlib
Group:          Productivity/Graphics/Other
Url:            https://pmt.sourceforge.io/pngcrush/
Source:         https://downloads.sourceforge.net/project/pmt/pngcrush/%{version}/%{name}-%{version}.tar.xz
Source1:        https://downloads.sourceforge.net/project/pmt/pngcrush/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
pngcrush is an excellent batch-mode compression utility for PNG
images. Depending on the application that created the original PNGs, it can
improve the file size anywhere from a few percent to 40%% or more (completely
losslessly). The utility also allows specified PNG chunks (e.g. text comments)
to be inserted or deleted, and it can fix incorrect gamma info written by
Photoshop 5.0 as well as the erroneous iCCP chunk written by Photoshop 5.5.

%prep
%setup -q

%build
make -f Makefile-nolib %{?_smp_mflags} \
	PNGINC="$(pkg-config --variable includedir libpng)" \
	PNGLIB="$(pkg-config --variable libdir libpng)" \
	ZINC="$(pkg-config --variable includedir zlib)" \
	ZLIB="$(pkg-config --variable libdir zlib)" \
	CFLAGS="%{optflags}"

%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 pngcrush %{buildroot}%{_bindir}

%files
%defattr(-,root,root)
%doc ChangeLog.html LICENSE
%{_bindir}/pngcrush

%changelog
* Sun Nov  5 2017 vilene@posteo.net
- Update to new upstream release 1.8.13:
  * Made "-reduce" the default behavior.  Removed obsolete options
    "-plte_len", "-cc", "-nocc", "-double_gamma", "-already_crushed",
    and "-bit_depth".
  * Added "-speed" option; it avoids using the AVG or PAETH filters
    which are slower to decode.
  * Made "-force" force output even when the IDAT is larger, and
    added "-noforce" option; "-noforce" is now the default behavior.
  * Added "-warn" option, to show only warnings.
  * Changed default verbosity from 1 (normal) to 0 (quiet). Use "-v"
    to get the previous default behavior and "-v -v" to get the
    previous "verbose" behavior. The "-s" (silent) and "-q" (quiet)
    options behave as before.
- Remove pngcrush-systemlib.diff: not needed anymore.
- Add package source verification.
* Mon Aug 22 2016 stefan.bruens@rwth-aachen.de
- Add pngcrush-systemlib.diff
  Allow building with system libpng where possible, this fixes
  build errors on Aarch64 due to incomplete bundled libpng source
- Drop pngcrush-makefile-add-optflags.diff
  Supply optflags via CFLAGS, supported by current Makefile
* Sun Jan 17 2016 jengelh@inai.de
- Update to new upstream release 1.7.92
  * Fixed segfault while writing a -loco MNG
  * Eliminated a potential overflow while adding iTXt chunk
  * Fixed a double-free bug (CVE-2015-7700). There was a "free" of
  the sPLT chunk structure in pngcrush and then again in png.c.
  * Increased some buffer sizes in an attempt to prevent possible
  overflows.
  * Increased maximum size of a text chunk input from 260 to 2048
  (STR_BUF_SIZE) bytes, to agree with the help screen
  * Fixed bug that caused text chunks after IDAT to be written only
  when the "-save" option is used.
* Wed Mar 25 2015 meissner@suse.com
- updated to 1.7.85
  - Improved reporting of invalid chunk names. Does not try to put
    non-printable characters in STDERR; displays hex numbers instead.
  - Fixed include path for utime.h on MSVC (Louis McLaughlin).
  - Eliminated "FAR" memory support (it was removed from libpng at version 1.6.0).
  - Disabled the "-already_crushed" option which does not really work well.
* Mon Mar  2 2015 meissner@suse.com
- updated to 1.7.84
  - pngcrush-1.7.84 fixes more Coverity-scan defects (none are reported
    now), so it should be more resistant to crashes due to malformed
    input files.
- license adjusted to meet spdx.org, legal says "Zlib"
- run spec-cleaner
* Sat Oct 25 2014 opensuse@dstoecker.de
- update to 1.7.78
* Mon Sep  3 2012 opensuse@dstoecker.de
- update to version 1.7.37
* Mon Aug 20 2012 pascal.bleser@opensuse.org
- update to 1.7.35: performance optimizations
* Tue May 29 2012 opensuse@dstoecker.de
- update to version 1.7.28
* Mon Apr 23 2012 opensuse@dstoecker.de
- update to version 1.7.27
* Mon Feb 20 2012 opensuse@dstoecker.de
- update to version 1.7.25
* Tue Jan 31 2012 opensuse@dstoecker.de
- update to version 1.7.24
* Fri Jan  6 2012 opensuse@dstoecker.de
- update to new version 1.7.22
* Sat Nov 12 2011 pascal.bleser@opensuse.org
- rebase patches for 1.7.21
- complete the license tag a bit
- modernize spec file slightly
* Wed Nov  9 2011 opensuse@dstoecker.de
- update to new version 1.7.21
* Wed Sep 14 2011 opensuse@dstoecker.de
- update to 1.7.17
* Wed Jul 13 2011 opensuse@dstoecker.de
- update to 1.7.16
* Wed Mar 23 2011 opensuse@dstoecker.de
- update to 1.7.15
* Wed Jan 26 2011 opensuse@dstoecker.de
- update to 1.7.14
* Mon Aug  9 2010 opensuse@dstoecker.de
- update to 1.7.12
* Mon May 10 2010 opensuse@dstoecker.de
- update to 1.7.11
* Mon Mar 15 2010 opensuse@dstoecker.de
- update to 1.7.10
* Mon Mar  8 2010 opensuse@dstoecker.de
- update to 1.7.9
* Mon Jul 21 2008 opensuse@dstoecker.de
- update to 1.7.7
* Mon Jul 21 2008 opensuse@dstoecker.de
- copied to BuildService
  Fri Jun 13 12:00:00 UTC 2008 - Pascal Bleser
- new upstream version
  Sun May 11 12:00:00 UTC 2008 - Pascal Bleser
- moved to Packman
- new upstream version
  Tue Aug 14 12:00:00 UTC 2007 - Pascal Bleser
- use internal libpng macros, fixes build on 10.2
- fixed all compiler warnings
  Sat Jun 10 12:00:00 UTC 2006 - Pascal Bleser
- new package
